#
# spec file for package perl-Authen-SASL
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Authen-SASL
Version:        2.16
Release:        1.3.1
%define cpan_name Authen-SASL
Summary:        SASL Authentication framework
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Authen-SASL/
Source0:        https://cpan.metacpan.org/authors/id/G/GB/GBARR/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
Patch0:         perl526.path
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Digest::HMAC_MD5)
Requires:       perl(Digest::HMAC_MD5)
Recommends:     perl(GSSAPI)
%{perl_requires}

%description
SASL is a generic mechanism for authentication used by several network
protocols. *Authen::SASL* provides an implementation framework that all
protocols should be able to share.

The framework allows different implementations of the connection class to
be plugged in. At the time of writing there were two such plugins.

* Authen::SASL::Perl

This module implements several mechanisms and is implemented entirely in
Perl.

* Authen::SASL::XS

This module uses the Cyrus SASL C-library (both version 1 and 2 are
supported).

* Authen::SASL::Cyrus

This module is the predecessor to Authen::SASL::XS. It is reccomended to
use Authen::SASL::XS

By default the order in which these plugins are selected is
Authen::SASL::XS, Authen::SASL::Cyrus and then Authen::SASL::Perl.

If you want to change it or want to specifically use one implementation
only simply do

 use Authen::SASL qw(Perl);

or if you have another plugin module that supports the Authen::SASL API

 use Authen::SASL qw(My::SASL::Plugin);

%prep
%setup -q -n %{cpan_name}-%{version}
%patch0 -p1

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc api.txt Changes compat_pl example_pl

%changelog
* Fri Sep 29 2017 coolo@suse.com
- add perl526.path to build with perl 5.26
* Mon Jun  3 2013 coolo@suse.com
- updated to 2.16
  * SASL.pod: fix typo [Peter Marschall]
  * Perl.pm: avoid warning on "uninitialized value" [Peter Marschall]
* Thu Nov 17 2011 coolo@suse.com
- use original tar
* Mon May 16 2011 vcizek@novell.com
- update to 2.15
  * Makes sure that user callbacks are called [Yann Kerherve]
- license correction
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sun Apr  4 2010 chris@computersalat.de
- update to 2.1401
  * Add META.yml to release
- cleanup spec
  * sort TAGS
  * update Url
  * fix deps
  - BuildReq perl
  - Build-/Req Digest::MD5, Digest::HMAC_MD5
  * added compat_pl, SIGNATURE to doc
- added perl-macros
* Fri Mar 26 2010 anicka@suse.cz
- update to 2.14
  * Documentation updates
  * Added server API description
  * Bugfixes to LOGIN, PLAIN and DIGEST_MD5
  * Added server support for LOGIN, PLAINaand DIGEST_MD5
  * Compatiblity with Authen::SASL::XS
* Wed Jan 13 2010 anicka@suse.cz
- update to 2.13
  * RT#42191 Only use pass for GSSAPI credentials if it is an
    object of type GSSAPI::Cred
  * RT#675 Authorization with Authen::SASL::Perl::External
  * Call client_new and server_new inside eval so further plugins
    can be tried before failing
  * Prefer to use Authen::SASL::XS over Authen::SASL::Cyrus
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Fri Jul 25 2008 anicka@suse.cz
- update to 2.12
  * GSSAPI implement protocol according to RFC, but by default,
    remain compatible with cyrus sasl lib
  * DIGEST-MD5 implement channel encryption layer
* Thu Jun 19 2008 anicka@suse.cz
- update to 2.11
  * implement securesocket() in the ::Perl set of plugins
  * fix parsing challenges from GnuSASL
  * update tests for DIGEST-MD5
  * New test from Phil Pennock for testing final server response
* Thu Jul 13 2006 anicka@suse.cz
- update to 2.10
  * Added Authen::SASL::Perl::GSSAPI
  * Added error method to Authen::SASL to obtain error
    from last connection
  * bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jul 27 2005 mt@suse,de
- update to 2.09
* Fri Aug 13 2004 mjancar@suse.cz
- update to 2.08
* Tue Mar  2 2004 mjancar@suse.cz
- add perl-Digest-HMAC to neededforbuild
* Thu Feb 26 2004 mjancar@suse.cz
- update to 2.06
* Wed Oct 22 2003 mjancar@suse.cz
- update to 2.05
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Wed Jun 18 2003 mjancar@suse.cz
- update to 2.04
- fix filelist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Sat Dec 28 2002 prehak@suse.cz
- initial version 2.02 of this package
